@@ -110,16 +110,16 @@ class Contracts:
 
     # def to_pdf(self, regex): under construction, to include functions from strategy_extract to export pdf of only regexed contents
 
-in_path = sys.argv[1]
-out_path = sys.argv[2]
-chapter = sys.argv[3]
-sections = list(sys.argv[4:])
+# in_path = sys.argv[1]
+# out_path = sys.argv[2]
+# chapter = sys.argv[3]
+# sections = list(sys.argv[4:])
 
-def main():
-    contracts = Contracts(in_path)
-    contracts.to_excel(contracts.get_df(contracts.get_sections(chapter, sections)), out_path) # works
+# def main():
+#     contracts = Contracts(in_path)
+#     contracts.to_excel(contracts.get_df(contracts.get_sections(chapter, sections)), out_path) # works
 
-if __name__=='__main__':
+# if __name__=='__main__':
 
     ### single contract class
     # contract = Contract('/Users/andy/Desktop/work/ubiquant/ͬȡ/ҳͶʲȡ//׾ѡ2˽ļ֤ȯͶʻͬйܰ-ݵһβЭ£Ͷʶ˺£V1.2.8TX-20210302壩.docx')
@@ -128,4 +128,4 @@ if __name__=='__main__':
 
     ### folder of contracts class
     
-    main()
\ No newline at end of file
+    # main()
\ No newline at end of file
